@@ -20,8 +20,12 @@ options:
     description: SiteId path parameter. Site id to which site details to be deleted.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+- dnacentersdk >= 2.6.0
+- python >= 3.9
+seealso:
+- name: Cisco DNA Center documentation for Sites DeleteSite
+  description: Complete reference of the DeleteSite API.
+  link: https://developer.cisco.com/docs/dna-center/#!delete-site
 notes:
   - SDK Method used are
     sites.Sites.delete_site,
@@ -52,7 +56,8 @@ dnac_response:
   type: dict
   sample: >
     {
-      "status": "string",
+      "executionId": "string",
+      "executionStatusURL": "string",
       "message": "string"
     }
 """
