@@ -20,8 +20,12 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+- dnacentersdk >= 2.6.0
+- python >= 3.9
+seealso:
+- name: Cisco DNA Center documentation for Tag GetTagResourceTypes
+  description: Complete reference of the GetTagResourceTypes API.
+  link: https://developer.cisco.com/docs/dna-center/#!get-tag-resource-types
 notes:
   - SDK Method used are
     tag.Tag.get_tag_resource_types,
@@ -41,8 +45,7 @@ EXAMPLES = r"""
     dnac_port: "{{dnac_port}}"
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
-    headers:
-      custom: value
+    headers: "{{my_headers | from_json}}"
   register: result
 
 """
