@@ -7,9 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: backup_restore
-short_description: Resource module for Backup Restore
+short_description: Resource module for Backup RESTore
 description:
-- Manage operation create of the resource Backup Restore.
+- Manage operation create of the resource Backup RESTore.
+- Triggers a configuration DB restore job on the ISE node. The API returns the task ID. Use the Task Service status API to get the status of the backup job.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -29,13 +30,19 @@ options:
       true, false.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Backup Restore reference
-  description: Complete reference of the Backup Restore object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Backup And Restore
+  description: Complete reference of the Backup And Restore API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!backup-and-restore-open-api
+notes:
+  - SDK Method used are
+    backup_and_restore.BackupAndRestore.restore_config_backup,
+
+  - Paths used are
+    post /api/v1/backup-restore/config/restore,
+
 """
 
 EXAMPLES = r"""
