@@ -11,6 +11,8 @@ short_description: Information module for Native Supplicant Profile
 description:
 - Get all Native Supplicant Profile.
 - Get Native Supplicant Profile by id.
+- This API allows the client to get a native supplicant profile by ID.
+- This API allows the client to get all the native supplicant profiles.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -29,13 +31,21 @@ options:
     - Size query parameter. Number of objects returned per page.
     type: int
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Native Supplicant Profile reference
-  description: Complete reference of the Native Supplicant Profile object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for NativeSupplicantProfile
+  description: Complete reference of the NativeSupplicantProfile API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!nspprofile
+notes:
+  - SDK Method used are
+    native_supplicant_profile.NativeSupplicantProfile.get_native_supplicant_profile_by_id,
+    native_supplicant_profile.NativeSupplicantProfile.get_native_supplicant_profile_generator,
+
+  - Paths used are
+    get /ers/config/nspprofile,
+    get /ers/config/nspprofile/{id},
+
 """
 
 EXAMPLES = r"""
@@ -85,10 +95,11 @@ ise_response:
         "type": "string"
       }
     }
+
 ise_responses:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: list
   elements: dict
   sample: >
@@ -97,6 +108,15 @@ ise_responses:
         "id": "string",
         "name": "string",
         "description": "string",
+        "wirelessProfiles": [
+          {
+            "ssid": "string",
+            "allowedProtocol": "string",
+            "certificateTemplateId": "string",
+            "actionType": "string",
+            "previousSsid": "string"
+          }
+        ],
         "link": {
           "rel": "string",
           "href": "string",
