@@ -10,19 +10,29 @@ module: network_access_local_exception_rules_reset_hitcounts
 short_description: Resource module for Network Access Local Exception Rules Reset Hitcounts
 description:
 - Manage operation create of the resource Network Access Local Exception Rules Reset Hitcounts.
+- Network Access - Reset HitCount for local exceptions.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  policyId:
+    description: PolicyId path parameter. Policy id.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Local Exception Rules Reset Hitcounts reference
-  description: Complete reference of the Network Access Local Exception Rules Reset Hitcounts object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Authorization Exception Rules
+  description: Complete reference of the Network Access - Authorization Exception Rules API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_authorization_exception_rules.NetworkAccessAuthorizationExceptionRules.reset_hit_counts_network_access_local_exceptions,
+
+  - Paths used are
+    post /network-access/policy-set/{policyId}/exception/reset-hitcount,
+
 """
 
 EXAMPLES = r"""
@@ -32,6 +42,7 @@ EXAMPLES = r"""
     ise_username: "{{ise_username}}"
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
+    policyId: string
 
 """
 
