@@ -7,26 +7,36 @@
 DOCUMENTATION = r"""
 ---
 module: sg_mapping_deploy
-short_description: Resource module for Sg Mapping Deploy
+short_description: Resource module for SG Mapping Deploy
 description:
-- Manage operation update of the resource Sg Mapping Deploy.
+- Manage operation update of the resource SG Mapping Deploy.
+- This API allows the client to deploy an IP to SGT mapping by ID.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  id:
+    description: Id path parameter.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Sg Mapping Deploy reference
-  description: Complete reference of the Sg Mapping Deploy object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for IPToSGTMapping
+  description: Complete reference of the IPToSGTMapping API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!sgmapping
+notes:
+  - SDK Method used are
+    ip_to_sgt_mapping.IpToSgtMapping.deploy_ip_to_sgt_mapping_by_id,
+
+  - Paths used are
+    put /ers/config/sgmapping/{id}/deploy,
+
 """
 
 EXAMPLES = r"""
-- name: Update by id
+- name: Update all
   cisco.ise.sg_mapping_deploy:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
