@@ -10,6 +10,7 @@ module: system_certificate_export_info
 short_description: Information module for System Certificate Export Info
 description:
 - Get System Certificate Export Info.
+- Export System Certificate.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -21,6 +22,13 @@ options:
   export:
     description: System Certificate Export Info's export.
     type: str
+  filename:
+    description: The filename used to save the download file.
+    type: str
+  hostName:
+    description: Hostname of the Cisco ISE node in which self-signed certificate should
+      be generated.
+    type: str
   id:
     description: System Certificate Export Info's id.
     type: str
@@ -31,13 +39,18 @@ options:
     description: Enable or disable automatic file creation of raw response.
     type: bool
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: System Certificate Export Info reference
-  description: Complete reference of the System Certificate Export Info object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Certificates
+  description: Complete reference of the Certificates API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!certificate-openapi
+notes:
+  - SDK Method used are
+    certificates.Certificates.export_system_certificate,
+
+  - Paths used are
+
 """
 
 EXAMPLES = r"""
@@ -49,6 +62,8 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     dirPath: /tmp/downloads/
     export: string
+    filename: download_filename.extension
+    hostName: string
     id: string
     password: string
     saveFile: true
@@ -60,6 +75,15 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {
+      "description": "string",
+      "file": "string",
+      "filename": "string",
+      "inputStream": {},
+      "open": true,
+      "readable": true,
+      "uri": "string",
+      "url": "string"
+    }
 """
