@@ -3,6 +3,7 @@
 
 # Copyright: (c) 2018, Dag Wieers (@dagwieers) <dag@wieers.com>
 # Copyright: (c) 2020, Cindy Zhao (@cizhao) <cizhao@cisco.com>
+# Copyright: (c) 2023, Anvitha Jain (@anvjain) <anvjain@cisco.com>
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
@@ -40,6 +41,22 @@ options:
     - Admin user is always added to the associated user list irrespective of this parameter being used.
     type: list
     elements: str
+  remote_users:
+    description:
+    - A list of associated remote users for this tenant.
+    type: list
+    elements: dict
+    suboptions:
+      name:
+        description:
+        - The name of the associated remote user for this tenant.
+        required: true
+        type: str
+      login_domain:
+        description:
+        - Domain name of the associated remote user for this tenant.
+        required: true
+        type: str
   sites:
     description:
     - A list of associated sites for this tenant.
@@ -73,7 +90,6 @@ EXAMPLES = r"""
     display_name: North European Datacenter
     description: This tenant manages the NEDC environment.
     state: present
-  delegate_to: localhost
 
 - name: Remove a tenant from MSO and Site/APIC
   cisco.mso.mso_tenant:
@@ -83,7 +99,6 @@ EXAMPLES = r"""
     tenant: north_europe
     orchestrator_only: no
     state: absent
-  delegate_to: localhost
 
 - name: Remove a tenant from MSO only
   cisco.mso.mso_tenant:
@@ -93,7 +108,6 @@ EXAMPLES = r"""
     tenant: north_europe
     orchestrator_only: yes
     state: absent
-  delegate_to: localhost
 
 - name: Query a tenant
   cisco.mso.mso_tenant:
@@ -102,7 +116,6 @@ EXAMPLES = r"""
     password: SomeSecretPassword
     tenant: north_europe
     state: query
-  delegate_to: localhost
   register: query_result
 
 - name: Query all tenants
@@ -111,7 +124,6 @@ EXAMPLES = r"""
     username: admin
     password: SomeSecretPassword
     state: query
-  delegate_to: localhost
   register: query_result
 """
 
@@ -119,7 +131,7 @@ RETURN = r"""
 """
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.cisco.mso.plugins.module_utils.mso import MSOModule, mso_argument_spec
+from ansible_collections.cisco.mso.plugins.module_utils.mso import MSOModule, mso_argument_spec, ndo_remote_user_spec
 from ansible_collections.cisco.mso.plugins.module_utils.constants import YES_OR_NO_TO_BOOL_STRING_MAP
 
 
@@ -130,6 +142,7 @@ def main():
         display_name=dict(type="str"),
         tenant=dict(type="str", aliases=["name"]),
         users=dict(type="list", elements="str"),
+        remote_users=dict(type="list", elements="dict", options=ndo_remote_user_spec()),
         sites=dict(type="list", elements="str"),
         orchestrator_only=dict(type="str", default="yes", choices=["yes", "no"]),
         state=dict(type="str", default="present", choices=["absent", "present", "query"]),
@@ -149,13 +162,10 @@ def main():
     tenant = module.params.get("tenant")
     orchestrator_only = module.params.get("orchestrator_only")
     state = module.params.get("state")
+    remote_users = module.params.get("remote_users")
 
     mso = MSOModule(module)
 
-    # Convert sites and users
-    sites = mso.lookup_sites(module.params.get("sites"))
-    users = mso.lookup_users(module.params.get("users"))
-
     tenant_id = None
     path = "tenants"
 
@@ -182,6 +192,12 @@ def main():
                 mso.existing = mso.request(path, method="DELETE")
 
     elif state == "present":
+        # Convert sites and users
+        sites = mso.lookup_sites(module.params.get("sites"))
+        users = mso.lookup_users(module.params.get("users"))
+        if remote_users is not None:
+            users += mso.lookup_remote_users(remote_users)
+
         mso.previous = mso.existing
 
         payload = dict(
