@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2017, Eike Frost <ei@kefro.st>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -29,12 +30,18 @@ description:
       SAML-specific settings on an OpenID Connect client for instance and vice versa. Be careful.
       If you do not specify a setting, usually a sensible default is chosen.
 
+attributes:
+    check_mode:
+        support: full
+    diff_mode:
+        support: full
+
 options:
     state:
         description:
             - State of the client
-            - On C(present), the client will be created (or updated if it exists already).
-            - On C(absent), the client will be removed if it exists
+            - On V(present), the client will be created (or updated if it exists already).
+            - On V(absent), the client will be removed if it exists
         choices: ['present', 'absent']
         default: 'present'
         type: str
@@ -48,7 +55,7 @@ options:
     client_id:
         description:
             - Client id of client to be worked on. This is usually an alphanumeric name chosen by
-              you. Either this or I(id) is required. If you specify both, I(id) takes precedence.
+              you. Either this or O(id) is required. If you specify both, O(id) takes precedence.
               This is 'clientId' in the Keycloak REST API.
         aliases:
             - clientId
@@ -56,23 +63,23 @@ options:
 
     id:
         description:
-            - Id of client to be worked on. This is usually an UUID. Either this or I(client_id)
+            - Id of client to be worked on. This is usually an UUID. Either this or O(client_id)
               is required. If you specify both, this takes precedence.
         type: str
 
     name:
         description:
-            - Name of the client (this is not the same as I(client_id))
+            - Name of the client (this is not the same as O(client_id)).
         type: str
 
     description:
         description:
-            - Description of the client in Keycloak
+            - Description of the client in Keycloak.
         type: str
 
     root_url:
         description:
-            - Root URL appended to relative URLs for this client
+            - Root URL appended to relative URLs for this client.
               This is 'rootUrl' in the Keycloak REST API.
         aliases:
             - rootUrl
@@ -80,7 +87,7 @@ options:
 
     admin_url:
         description:
-            - URL to the admin interface of the client
+            - URL to the admin interface of the client.
               This is 'adminUrl' in the Keycloak REST API.
         aliases:
             - adminUrl
@@ -101,12 +108,12 @@ options:
 
     client_authenticator_type:
         description:
-            - How do clients authenticate with the auth server? Either C(client-secret) or
-              C(client-jwt) can be chosen. When using C(client-secret), the module parameter
-              I(secret) can set it, while for C(client-jwt), you can use the keys C(use.jwks.url),
-              C(jwks.url), and C(jwt.credential.certificate) in the I(attributes) module parameter
+            - How do clients authenticate with the auth server? Either V(client-secret) or
+              V(client-jwt) can be chosen. When using V(client-secret), the module parameter
+              O(secret) can set it, while for V(client-jwt), you can use the keys C(use.jwks.url),
+              C(jwks.url), and C(jwt.credential.certificate) in the O(attributes) module parameter
               to configure its behavior.
-              This is 'clientAuthenticatorType' in the Keycloak REST API.
+            - This is 'clientAuthenticatorType' in the Keycloak REST API.
         choices: ['client-secret', 'client-jwt']
         aliases:
             - clientAuthenticatorType
@@ -114,7 +121,7 @@ options:
 
     secret:
         description:
-            - When using I(client_authenticator_type) C(client-secret) (the default), you can
+            - When using O(client_authenticator_type=client-secret) (the default), you can
               specify a secret here (otherwise one will be generated if it does not exit). If
               changing this secret, the module will not register a change currently (but the
               changed secret will be saved).
@@ -239,9 +246,11 @@ options:
 
     protocol:
         description:
-            - Type of client (either C(openid-connect) or C(saml).
+            - Type of client.
+            - At creation only, default value will be V(openid-connect) if O(protocol) is omitted.
+            - The V(docker-v2) value was added in community.general 8.6.0.
         type: str
-        choices: ['openid-connect', 'saml']
+        choices: ['openid-connect', 'saml', 'docker-v2']
 
     full_scope_allowed:
         description:
@@ -279,7 +288,7 @@ options:
 
     use_template_config:
         description:
-            - Whether or not to use configuration from the I(client_template).
+            - Whether or not to use configuration from the O(client_template).
               This is 'useTemplateConfig' in the Keycloak REST API.
         aliases:
             - useTemplateConfig
@@ -287,7 +296,7 @@ options:
 
     use_template_scope:
         description:
-            - Whether or not to use scope configuration from the I(client_template).
+            - Whether or not to use scope configuration from the O(client_template).
               This is 'useTemplateScope' in the Keycloak REST API.
         aliases:
             - useTemplateScope
@@ -295,12 +304,21 @@ options:
 
     use_template_mappers:
         description:
-            - Whether or not to use mapper configuration from the I(client_template).
+            - Whether or not to use mapper configuration from the O(client_template).
               This is 'useTemplateMappers' in the Keycloak REST API.
         aliases:
             - useTemplateMappers
         type: bool
 
+    always_display_in_console:
+        description:
+            - Whether or not to display this client in account console, even if the
+              user does not have an active session.
+        aliases:
+            - alwaysDisplayInConsole
+        type: bool
+        version_added: 4.7.0
+
     surrogate_auth_required:
         description:
             - Whether or not surrogate auth is required.
@@ -318,6 +336,32 @@ options:
         aliases:
             - authorizationSettings
 
+    authentication_flow_binding_overrides:
+        description:
+            - Override realm authentication flow bindings.
+        type: dict
+        aliases:
+            - authenticationFlowBindingOverrides
+        version_added: 3.4.0
+
+    default_client_scopes:
+        description:
+            - List of default client scopes.
+        aliases:
+            - defaultClientScopes
+        type: list
+        elements: str
+        version_added: 4.7.0
+
+    optional_client_scopes:
+        description:
+            - List of optional client scopes.
+        aliases:
+            - optionalClientScopes
+        type: list
+        elements: str
+        version_added: 4.7.0
+
     protocol_mappers:
         description:
             - a list of dicts defining protocol mappers for this client.
@@ -349,38 +393,37 @@ options:
 
             protocol:
                 description:
-                    - This is either C(openid-connect) or C(saml), this specifies for which protocol this protocol mapper
-                      is active.
-                choices: ['openid-connect', 'saml']
+                    - This specifies for which protocol this protocol mapper is active.
+                choices: ['openid-connect', 'saml', 'docker-v2']
                 type: str
 
             protocolMapper:
                 description:
-                    - The Keycloak-internal name of the type of this protocol-mapper. While an exhaustive list is
+                    - "The Keycloak-internal name of the type of this protocol-mapper. While an exhaustive list is
                       impossible to provide since this may be extended through SPIs by the user of Keycloak,
-                      by default Keycloak as of 3.4 ships with at least
-                    - C(docker-v2-allow-all-mapper)
-                    - C(oidc-address-mapper)
-                    - C(oidc-full-name-mapper)
-                    - C(oidc-group-membership-mapper)
-                    - C(oidc-hardcoded-claim-mapper)
-                    - C(oidc-hardcoded-role-mapper)
-                    - C(oidc-role-name-mapper)
-                    - C(oidc-script-based-protocol-mapper)
-                    - C(oidc-sha256-pairwise-sub-mapper)
-                    - C(oidc-usermodel-attribute-mapper)
-                    - C(oidc-usermodel-client-role-mapper)
-                    - C(oidc-usermodel-property-mapper)
-                    - C(oidc-usermodel-realm-role-mapper)
-                    - C(oidc-usersessionmodel-note-mapper)
-                    - C(saml-group-membership-mapper)
-                    - C(saml-hardcode-attribute-mapper)
-                    - C(saml-hardcode-role-mapper)
-                    - C(saml-role-list-mapper)
-                    - C(saml-role-name-mapper)
-                    - C(saml-user-attribute-mapper)
-                    - C(saml-user-property-mapper)
-                    - C(saml-user-session-note-mapper)
+                      by default Keycloak as of 3.4 ships with at least:"
+                    - V(docker-v2-allow-all-mapper)
+                    - V(oidc-address-mapper)
+                    - V(oidc-full-name-mapper)
+                    - V(oidc-group-membership-mapper)
+                    - V(oidc-hardcoded-claim-mapper)
+                    - V(oidc-hardcoded-role-mapper)
+                    - V(oidc-role-name-mapper)
+                    - V(oidc-script-based-protocol-mapper)
+                    - V(oidc-sha256-pairwise-sub-mapper)
+                    - V(oidc-usermodel-attribute-mapper)
+                    - V(oidc-usermodel-client-role-mapper)
+                    - V(oidc-usermodel-property-mapper)
+                    - V(oidc-usermodel-realm-role-mapper)
+                    - V(oidc-usersessionmodel-note-mapper)
+                    - V(saml-group-membership-mapper)
+                    - V(saml-hardcode-attribute-mapper)
+                    - V(saml-hardcode-role-mapper)
+                    - V(saml-role-list-mapper)
+                    - V(saml-role-name-mapper)
+                    - V(saml-user-attribute-mapper)
+                    - V(saml-user-property-mapper)
+                    - V(saml-user-session-note-mapper)
                     - An exhaustive list of available mappers on your installation can be obtained on
                       the admin console by going to Server Info -> Providers and looking under
                       'protocol-mapper'.
@@ -389,10 +432,10 @@ options:
             config:
                 description:
                     - Dict specifying the configuration options for the protocol mapper; the
-                      contents differ depending on the value of I(protocolMapper) and are not documented
+                      contents differ depending on the value of O(protocol_mappers[].protocolMapper) and are not documented
                       other than by the source of the mappers and its parent class(es). An example is given
                       below. It is easiest to obtain valid config values by dumping an already-existing
-                      protocol mapper configuration through check-mode in the I(existing) field.
+                      protocol mapper configuration through check-mode in the RV(existing) field.
                 type: dict
 
     attributes:
@@ -436,7 +479,7 @@ options:
 
             saml.signature.algorithm:
                 description:
-                    - Signature algorithm used to sign SAML documents. One of C(RSA_SHA256), C(RSA_SHA1), C(RSA_SHA512), or C(DSA_SHA1).
+                    - Signature algorithm used to sign SAML documents. One of V(RSA_SHA256), V(RSA_SHA1), V(RSA_SHA512), or V(DSA_SHA1).
 
             saml.signing.certificate:
                 description:
@@ -461,15 +504,15 @@ options:
 
             saml_name_id_format:
                 description:
-                    - For SAML clients, the NameID format to use (one of C(username), C(email), C(transient), or C(persistent))
+                    - For SAML clients, the NameID format to use (one of V(username), V(email), V(transient), or V(persistent))
 
             saml_signature_canonicalization_method:
                 description:
                     - SAML signature canonicalization method. This is one of four values, namely
-                      C(http://www.w3.org/2001/10/xml-exc-c14n#) for EXCLUSIVE,
-                      C(http://www.w3.org/2001/10/xml-exc-c14n#WithComments) for EXCLUSIVE_WITH_COMMENTS,
-                      C(http://www.w3.org/TR/2001/REC-xml-c14n-20010315) for INCLUSIVE, and
-                      C(http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments) for INCLUSIVE_WITH_COMMENTS.
+                      V(http://www.w3.org/2001/10/xml-exc-c14n#) for EXCLUSIVE,
+                      V(http://www.w3.org/2001/10/xml-exc-c14n#WithComments) for EXCLUSIVE_WITH_COMMENTS,
+                      V(http://www.w3.org/TR/2001/REC-xml-c14n-20010315) for INCLUSIVE, and
+                      V(http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments) for INCLUSIVE_WITH_COMMENTS.
 
             saml_single_logout_service_url_post:
                 description:
@@ -481,12 +524,12 @@ options:
 
             user.info.response.signature.alg:
                 description:
-                    - For OpenID-Connect clients, JWA algorithm for signed UserInfo-endpoint responses. One of C(RS256) or C(unsigned).
+                    - For OpenID-Connect clients, JWA algorithm for signed UserInfo-endpoint responses. One of V(RS256) or V(unsigned).
 
             request.object.signature.alg:
                 description:
                     - For OpenID-Connect clients, JWA algorithm which the client needs to use when sending
-                      OIDC request object. One of C(any), C(none), C(RS256).
+                      OIDC request object. One of V(any), V(none), V(RS256).
 
             use.jwks.url:
                 description:
@@ -503,28 +546,38 @@ options:
                       client and signed by its key, base64-encoded.
 
 extends_documentation_fragment:
-- community.general.keycloak
-
+    - community.general.keycloak
+    - community.general.attributes
 
 author:
     - Eike Frost (@eikef)
 '''
 
 EXAMPLES = '''
-- name: Create or update Keycloak client (minimal example)
-  local_action:
-    module: keycloak_client
-    auth_client_id: admin-cli
+- name: Create or update Keycloak client (minimal example), authentication with credentials
+  community.general.keycloak_client:
     auth_keycloak_url: https://auth.example.com/auth
     auth_realm: master
     auth_username: USERNAME
     auth_password: PASSWORD
     client_id: test
     state: present
+  delegate_to: localhost
+
+
+- name: Create or update Keycloak client (minimal example), authentication with token
+  community.general.keycloak_client:
+    auth_client_id: admin-cli
+    auth_keycloak_url: https://auth.example.com/auth
+    auth_realm: master
+    token: TOKEN
+    client_id: test
+    state: present
+  delegate_to: localhost
+
 
 - name: Delete a Keycloak client
-  local_action:
-    module: keycloak_client
+  community.general.keycloak_client:
     auth_client_id: admin-cli
     auth_keycloak_url: https://auth.example.com/auth
     auth_realm: master
@@ -532,10 +585,11 @@ EXAMPLES = '''
     auth_password: PASSWORD
     client_id: test
     state: absent
+  delegate_to: localhost
+
 
 - name: Create or update a Keycloak client (with all the bells and whistles)
-  local_action:
-    module: keycloak_client
+  community.general.keycloak_client:
     auth_client_id: admin-cli
     auth_keycloak_url: https://auth.example.com/auth
     auth_realm: master
@@ -550,7 +604,7 @@ EXAMPLES = '''
     root_url: https://www.example.com/
     admin_url: https://www.example.com/admin_url
     base_url: basepath
-    enabled: True
+    enabled: true
     client_authenticator_type: client-secret
     secret: REALLYWELLKEPTSECRET
     redirect_uris:
@@ -559,22 +613,23 @@ EXAMPLES = '''
     web_origins:
       - https://www.example.com/*
     not_before: 1507825725
-    bearer_only: False
-    consent_required: False
-    standard_flow_enabled: True
-    implicit_flow_enabled: False
-    direct_access_grants_enabled: False
-    service_accounts_enabled: False
-    authorization_services_enabled: False
-    public_client: False
-    frontchannel_logout: False
+    bearer_only: false
+    consent_required: false
+    standard_flow_enabled: true
+    implicit_flow_enabled: false
+    direct_access_grants_enabled: false
+    service_accounts_enabled: false
+    authorization_services_enabled: false
+    public_client: false
+    frontchannel_logout: false
     protocol: openid-connect
     full_scope_allowed: false
     node_re_registration_timeout: -1
     client_template: test
-    use_template_config: False
+    use_template_config: false
     use_template_scope: false
-    use_template_mappers: no
+    use_template_mappers: false
+    always_display_in_console: true
     registered_nodes:
       node01.example.com: 1507828202
     registration_access_token: eyJWT_TOKEN
@@ -582,15 +637,17 @@ EXAMPLES = '''
     default_roles:
       - test01
       - test02
+    authentication_flow_binding_overrides:
+        browser: 4c90336b-bf1d-4b87-916d-3677ba4e5fbb
     protocol_mappers:
       - config:
-          access.token.claim: True
+          access.token.claim: true
           claim.name: "family_name"
-          id.token.claim: True
+          id.token.claim: true
           jsonType.label: String
           user.attribute: lastName
-          userinfo.token.claim: True
-        consentRequired: True
+          userinfo.token.claim: true
+        consentRequired: true
         consentText: "${familyName}"
         name: family name
         protocol: openid-connect
@@ -604,14 +661,14 @@ EXAMPLES = '''
         protocol: saml
         protocolMapper: saml-role-list-mapper
     attributes:
-      saml.authnstatement: True
-      saml.client.signature: True
-      saml.force.post.binding: True
-      saml.server.signature: True
+      saml.authnstatement: true
+      saml.client.signature: true
+      saml.force.post.binding: true
+      saml.server.signature: true
       saml.signature.algorithm: RSA_SHA256
       saml.signing.certificate: CERTIFICATEHERE
       saml.signing.private.key: PRIVATEKEYHERE
-      saml_force_name_id_format: False
+      saml_force_name_id_format: false
       saml_name_id_format: username
       saml_signature_canonicalization_method: "http://www.w3.org/2001/10/xml-exc-c14n#"
       user.info.response.signature.alg: RS256
@@ -619,24 +676,26 @@ EXAMPLES = '''
       use.jwks.url: true
       jwks.url: JWKS_URL_FOR_CLIENT_AUTH_JWT
       jwt.credential.certificate: JWT_CREDENTIAL_CERTIFICATE_FOR_CLIENT_AUTH
+  delegate_to: localhost
 '''
 
 RETURN = '''
 msg:
-  description: Message as to what action was taken
-  returned: always
-  type: str
-  sample: "Client testclient has been updated"
+    description: Message as to what action was taken.
+    returned: always
+    type: str
+    sample: "Client testclient has been updated"
 
 proposed:
-    description: client representation of proposed changes to client
+    description: Representation of proposed client.
     returned: always
     type: dict
     sample: {
       clientId: "test"
     }
+
 existing:
-    description: client representation of existing client (sample is truncated)
+    description: Representation of existing client (sample is truncated).
     returned: always
     type: dict
     sample: {
@@ -645,9 +704,10 @@ existing:
             "request.object.signature.alg": "RS256",
         }
     }
+
 end_state:
-    description: client representation of client after module execution (sample is truncated)
-    returned: always
+    description: Representation of client after module execution (sample is truncated).
+    returned: on success
     type: dict
     sample: {
         "adminUrl": "http://www.example.com/admin_url",
@@ -658,23 +718,66 @@ end_state:
 '''
 
 from ansible_collections.community.general.plugins.module_utils.identity.keycloak.keycloak import KeycloakAPI, camel, \
-    keycloak_argument_spec, get_token, KeycloakError
+    keycloak_argument_spec, get_token, KeycloakError, is_struct_included
 from ansible.module_utils.basic import AnsibleModule
+import copy
+
+
+PROTOCOL_OPENID_CONNECT = 'openid-connect'
+PROTOCOL_SAML = 'saml'
+PROTOCOL_DOCKER_V2 = 'docker-v2'
+CLIENT_META_DATA = ['authorizationServicesEnabled']
+
+
+def normalise_cr(clientrep, remove_ids=False):
+    """ Re-sorts any properties where the order so that diff's is minimised, and adds default values where appropriate so that the
+    the change detection is more effective.
+
+    :param clientrep: the clientrep dict to be sanitized
+    :param remove_ids: If set to true, then the unique ID's of objects is removed to make the diff and checks for changed
+                       not alert when the ID's of objects are not usually known, (e.g. for protocol_mappers)
+    :return: normalised clientrep dict
+    """
+    # Avoid the dict passed in to be modified
+    clientrep = clientrep.copy()
+
+    if 'attributes' in clientrep:
+        clientrep['attributes'] = list(sorted(clientrep['attributes']))
+
+    if 'defaultClientScopes' in clientrep:
+        clientrep['defaultClientScopes'] = list(sorted(clientrep['defaultClientScopes']))
+
+    if 'optionalClientScopes' in clientrep:
+        clientrep['optionalClientScopes'] = list(sorted(clientrep['optionalClientScopes']))
+
+    if 'redirectUris' in clientrep:
+        clientrep['redirectUris'] = list(sorted(clientrep['redirectUris']))
+
+    if 'protocolMappers' in clientrep:
+        clientrep['protocolMappers'] = sorted(clientrep['protocolMappers'], key=lambda x: (x.get('name'), x.get('protocol'), x.get('protocolMapper')))
+        for mapper in clientrep['protocolMappers']:
+            if remove_ids:
+                mapper.pop('id', None)
+
+            # Set to a default value.
+            mapper['consentRequired'] = mapper.get('consentRequired', False)
+
+    return clientrep
 
 
 def sanitize_cr(clientrep):
-    """ Removes probably sensitive details from a client representation
+    """ Removes probably sensitive details from a client representation.
 
     :param clientrep: the clientrep dict to be sanitized
     :return: sanitized clientrep dict
     """
-    result = clientrep.copy()
+    result = copy.deepcopy(clientrep)
     if 'secret' in result:
         result['secret'] = 'no_log'
     if 'attributes' in result:
         if 'saml.signing.private.key' in result['attributes']:
             result['attributes']['saml.signing.private.key'] = 'no_log'
-    return result
+    return normalise_cr(result)
 
 
 def main():
@@ -690,7 +793,7 @@ def main():
         consentText=dict(type='str'),
         id=dict(type='str'),
         name=dict(type='str'),
-        protocol=dict(type='str', choices=['openid-connect', 'saml']),
+        protocol=dict(type='str', choices=[PROTOCOL_OPENID_CONNECT, PROTOCOL_SAML, PROTOCOL_DOCKER_V2]),
         protocolMapper=dict(type='str'),
         config=dict(type='dict'),
     )
@@ -724,7 +827,7 @@ def main():
         authorization_services_enabled=dict(type='bool', aliases=['authorizationServicesEnabled']),
         public_client=dict(type='bool', aliases=['publicClient']),
         frontchannel_logout=dict(type='bool', aliases=['frontchannelLogout']),
-        protocol=dict(type='str', choices=['openid-connect', 'saml']),
+        protocol=dict(type='str', choices=[PROTOCOL_OPENID_CONNECT, PROTOCOL_SAML, PROTOCOL_DOCKER_V2]),
         attributes=dict(type='dict'),
         full_scope_allowed=dict(type='bool', aliases=['fullScopeAllowed']),
         node_re_registration_timeout=dict(type='int', aliases=['nodeReRegistrationTimeout']),
@@ -733,28 +836,27 @@ def main():
         use_template_config=dict(type='bool', aliases=['useTemplateConfig']),
         use_template_scope=dict(type='bool', aliases=['useTemplateScope']),
         use_template_mappers=dict(type='bool', aliases=['useTemplateMappers']),
+        always_display_in_console=dict(type='bool', aliases=['alwaysDisplayInConsole']),
+        authentication_flow_binding_overrides=dict(type='dict', aliases=['authenticationFlowBindingOverrides']),
         protocol_mappers=dict(type='list', elements='dict', options=protmapper_spec, aliases=['protocolMappers']),
         authorization_settings=dict(type='dict', aliases=['authorizationSettings']),
+        default_client_scopes=dict(type='list', elements='str', aliases=['defaultClientScopes']),
+        optional_client_scopes=dict(type='list', elements='str', aliases=['optionalClientScopes']),
     )
+
     argument_spec.update(meta_args)
 
     module = AnsibleModule(argument_spec=argument_spec,
                            supports_check_mode=True,
-                           required_one_of=([['client_id', 'id']]))
+                           required_one_of=([['client_id', 'id'],
+                                             ['token', 'auth_realm', 'auth_username', 'auth_password']]),
+                           required_together=([['auth_realm', 'auth_username', 'auth_password']]))
 
     result = dict(changed=False, msg='', diff={}, proposed={}, existing={}, end_state={})
 
     # Obtain access token, initialize API
     try:
-        connection_header = get_token(
-            base_url=module.params.get('auth_keycloak_url'),
-            validate_certs=module.params.get('validate_certs'),
-            auth_realm=module.params.get('auth_realm'),
-            client_id=module.params.get('auth_client_id'),
-            auth_username=module.params.get('auth_username'),
-            auth_password=module.params.get('auth_password'),
-            client_secret=module.params.get('auth_client_secret'),
-        )
+        connection_header = get_token(module.params)
     except KeycloakError as e:
         module.fail_json(msg=str(e))
 
@@ -764,12 +866,12 @@ def main():
     cid = module.params.get('id')
     state = module.params.get('state')
 
-    # convert module parameters to client representation parameters (if they belong in there)
+    # Filter and map the parameters names that apply to the client
     client_params = [x for x in module.params
                      if x not in list(keycloak_argument_spec().keys()) + ['state', 'realm'] and
                      module.params.get(x) is not None]
-    keycloak_argument_spec().keys()
-    # See whether the client already exists in Keycloak
+
+    # See if it already exists in Keycloak
     if cid is None:
         before_client = kc.get_client_by_clientid(module.params.get('client_id'), realm=realm)
         if before_client is not None:
@@ -778,10 +880,10 @@ def main():
         before_client = kc.get_client_by_id(cid, realm=realm)
 
     if before_client is None:
-        before_client = dict()
+        before_client = {}
 
     # Build a proposed changeset from parameters given to this module
-    changeset = dict()
+    changeset = {}
 
     for client_param in client_params:
         new_param_value = module.params.get(client_param)
@@ -800,54 +902,65 @@ def main():
 
         changeset[camel(client_param)] = new_param_value
 
-    # Whether creating or updating a client, take the before-state and merge the changeset into it
-    updated_client = before_client.copy()
-    updated_client.update(changeset)
+    # Prepare the desired values using the existing values (non-existence results in a dict that is save to use as a basis)
+    desired_client = before_client.copy()
+    desired_client.update(changeset)
 
     result['proposed'] = sanitize_cr(changeset)
     result['existing'] = sanitize_cr(before_client)
 
-    # If the client does not exist yet, before_client is still empty
-    if before_client == dict():
+    # Cater for when it doesn't exist (an empty dict)
+    if not before_client:
         if state == 'absent':
-            # do nothing and exit
+            # Do nothing and exit
             if module._diff:
                 result['diff'] = dict(before='', after='')
-            result['msg'] = 'Client does not exist, doing nothing.'
+            result['changed'] = False
+            result['end_state'] = {}
+            result['msg'] = 'Client does not exist; doing nothing.'
             module.exit_json(**result)
 
-        # create new client
+        # Process a creation
         result['changed'] = True
-        if 'clientId' not in updated_client:
+
+        if 'clientId' not in desired_client:
             module.fail_json(msg='client_id needs to be specified when creating a new client')
+        if 'protocol' not in desired_client:
+            desired_client['protocol'] = PROTOCOL_OPENID_CONNECT
 
         if module._diff:
-            result['diff'] = dict(before='', after=sanitize_cr(updated_client))
+            result['diff'] = dict(before='', after=sanitize_cr(desired_client))
 
         if module.check_mode:
             module.exit_json(**result)
 
-        kc.create_client(updated_client, realm=realm)
-        after_client = kc.get_client_by_clientid(updated_client['clientId'], realm=realm)
+        # create it
+        kc.create_client(desired_client, realm=realm)
+        after_client = kc.get_client_by_clientid(desired_client['clientId'], realm=realm)
 
         result['end_state'] = sanitize_cr(after_client)
 
-        result['msg'] = 'Client %s has been created.' % updated_client['clientId']
+        result['msg'] = 'Client %s has been created.' % desired_client['clientId']
         module.exit_json(**result)
+
     else:
         if state == 'present':
-            # update existing client
+            # Process an update
             result['changed'] = True
+
             if module.check_mode:
                 # We can only compare the current client with the proposed updates we have
+                before_norm = normalise_cr(before_client, remove_ids=True)
+                desired_norm = normalise_cr(desired_client, remove_ids=True)
                 if module._diff:
-                    result['diff'] = dict(before=sanitize_cr(before_client),
-                                          after=sanitize_cr(updated_client))
-                result['changed'] = (before_client != updated_client)
+                    result['diff'] = dict(before=sanitize_cr(before_norm),
+                                          after=sanitize_cr(desired_norm))
+                result['changed'] = not is_struct_included(desired_norm, before_norm, CLIENT_META_DATA)
 
                 module.exit_json(**result)
 
-            kc.update_client(cid, updated_client, realm=realm)
+            # do the update
+            kc.update_client(cid, desired_client, realm=realm)
 
             after_client = kc.get_client_by_id(cid, realm=realm)
             if before_client == after_client:
@@ -855,25 +968,29 @@ def main():
             if module._diff:
                 result['diff'] = dict(before=sanitize_cr(before_client),
                                       after=sanitize_cr(after_client))
+
             result['end_state'] = sanitize_cr(after_client)
 
-            result['msg'] = 'Client %s has been updated.' % updated_client['clientId']
+            result['msg'] = 'Client %s has been updated.' % desired_client['clientId']
             module.exit_json(**result)
+
         else:
-            # Delete existing client
+            # Process a deletion (because state was not 'present')
             result['changed'] = True
+
             if module._diff:
-                result['diff']['before'] = sanitize_cr(before_client)
-                result['diff']['after'] = ''
+                result['diff'] = dict(before=sanitize_cr(before_client), after='')
 
             if module.check_mode:
                 module.exit_json(**result)
 
+            # delete it
             kc.delete_client(cid, realm=realm)
-            result['proposed'] = dict()
-            result['end_state'] = dict()
+            result['proposed'] = {}
+
+            result['end_state'] = {}
+
             result['msg'] = 'Client %s has been deleted.' % before_client['clientId']
-            module.exit_json(**result)
 
     module.exit_json(**result)
 
