@@ -1,4 +1,4 @@
-# (c) 2020-2022, NetApp, Inc
+# (c) 2020-2023, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' Unit Tests NetApp ONTAP REST APIs Ansible module: na_ontap_rest_info '''
@@ -10,8 +10,8 @@ __metaclass__ = type
 import pytest
 import sys
 
-from ansible_collections.netapp.ontap.tests.unit.compat import unittest
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import call_main, create_module, \
     expect_and_capture_ansible_exception, patch_ansible, create_and_apply, assert_warning_was_raised, print_warnings
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import \
@@ -56,6 +56,12 @@ SRR = rest_responses({
                          'records': [{'name': 'dummy_vol1'},
                                      {'name': 'dummy_vol2'}],
                          'version': 'ontap_version'}, None),
+    'get_subset_info_without_hal_links': (200,
+                                          {'num_records': 3,
+                                           'records': [{'name': 'dummy_vol1'},
+                                                       {'name': 'dummy_vol2'},
+                                                       {'name': 'dummy_vol3'}],
+                                           'version': 'ontap_version'}, None),
     'metrocluster_post': (200,
                           {'job': {
                               'uuid': 'fde79888-692a-11ea-80c2-005056b39fe7',
@@ -617,6 +623,17 @@ def set_default_args():
     })
 
 
+def set_args_run_ontap_gather_facts_disable_hal_links():
+    return dict({
+        'hostname': 'hostname',
+        'username': 'username',
+        'password': 'password',
+        'https': True,
+        'validate_certs': False,
+        'hal_linking': False
+    })
+
+
 def set_args_run_ontap_version_check():
     return dict({
         'hostname': 'hostname',
@@ -763,6 +780,19 @@ def test_version_warning_message():
                               'your version of ONTAP cluster/metrocluster/diagnostics requires (9, 8), ')
 
 
+def test_owning_resource_warning_message():
+    gather_subset = ['cluster/nodes']
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_96']),
+        ('GET', 'storage/volumes', SRR['get_subset_info']),
+    ])
+    extra_args = {
+        'owning_resource': {'svm_name': 'testSVM'}
+    }
+    create_and_apply(ontap_rest_info_module, set_args_run_ontap_version_check(), extra_args)
+    assert_warning_was_raised("Kindly refer to Ansible documentation to check the subsets that support option 'owning_resource'.")
+
+
 # metrocluster/diagnostics doesn't call get_subset_info and has 3 api calls instead of 1
 def test_run_metrocluster_pass():
     gather_subset = ['cluster/metrocluster/diagnostics']
@@ -981,6 +1011,16 @@ def test_demo_subset():
     assert 'cluster/nodes' in call_main(my_main, set_default_args(), {'gather_subset': 'demo'})['ontap_info']
 
 
+def test_demo_subset_without_hal_links():
+    register_responses([
+        ('GET', 'cluster', SRR['validate_ontap_version_pass']),
+        ('GET', 'cluster/software', SRR['get_subset_info_without_hal_links']),
+        ('GET', 'svm/svms', SRR['get_subset_info_without_hal_links']),
+        ('GET', 'cluster/nodes', SRR['get_subset_info_without_hal_links']),
+    ])
+    assert 'cluster/nodes' in call_main(my_main, set_args_run_ontap_gather_facts_disable_hal_links(), {'gather_subset': 'demo'})['ontap_info']
+
+
 def test_subset_with_default_fields():
     register_responses([
         ('GET', 'cluster', SRR['validate_ontap_version_pass']),
