@@ -6,11 +6,12 @@ __metaclass__ = type
 
 import os
 import sys
+
 import pynetbox
 from packaging import version
 
-# NOTE: If anything depends on specific versions of NetBox, can check INTEGRATION_TESTS in env
-# os.environ["INTEGRATION_TESTS"]
+# NOTE: If anything depends on specific versions of NetBox, can check VERSION in env
+# os.environ["VERSION"]
 
 
 # Set nb variable to connect to NetBox and use the veriable in future calls
@@ -173,6 +174,20 @@ vlans = [
 ]
 created_vlans = make_netbox_calls(nb.ipam.vlans, vlans)
 
+## Create FHRP GROUPS
+fhrp_groups = [
+    {
+        "protocol": "other",
+        "group_id": 1,
+        "description": "Test FHRP Group 1",
+    },
+    {
+        "protocol": "glbp",
+        "group_id": 2,
+        "description": "Test FHRP Group 2",
+    },
+]
+created_fhrp_groups = make_netbox_calls(nb.ipam.fhrp_groups, fhrp_groups)
 
 ## Create IPAM Roles
 ipam_roles = [{"name": "Network of care", "slug": "network-of-care"}]
@@ -328,6 +343,11 @@ if nb_version >= version.parse("2.11"):
     devices[0]["location"] = created_rack_groups[0].id
     devices[1]["location"] = created_rack_groups[0].id
     devices[3]["location"] = created_rack_groups[0].id
+# TODO: Remove this logic and adjust payload from device_role -> role once Netbox 3.6 or greater is supported.
+if nb_version >= version.parse("3.6"):
+    for device in devices:
+        if "device_role" in device:
+            device["role"] = device.pop("device_role")
 
 created_devices = make_netbox_calls(nb.dcim.devices, devices)
 ### Device variables to be used later on
@@ -446,6 +466,15 @@ test100_vm = nb.virtualization.virtual_machines.get(name="test100-vm")
 test101_vm = nb.virtualization.virtual_machines.get(name="test101-vm")
 test_spaces_vm = nb.virtualization.virtual_machines.get(name="Test VM With Spaces")
 
+# Create Virtaul Disks
+virtual_disks = [
+    {"name": "disk1", "size": 60, "virtual_machine": test100_vm.id},
+    {"name": "disk2", "size": 110, "virtual_machine": test100_vm.id},
+]
+created_virtual_disks = make_netbox_calls(
+    nb.virtualization.virtual_disks, virtual_disks
+)
+
 ## Create Virtual Machine Interfaces
 virtual_machines_intfs = [
     # Create test100-vm intfs
@@ -532,6 +561,23 @@ route_targets = [
 ]
 created_route_targets = make_netbox_calls(nb.ipam.route_targets, route_targets)
 
+## Create L2VPNs
+l2vpns = [
+    {
+        "identifier": 111111,
+        "name": "Test L2VPN 1",
+        "slug": "Test_L2VPN_1",
+        "type": "vxlan",
+    },
+    {
+        "identifier": 222222,
+        "name": "Test L2VPN 2",
+        "slug": "Test_L2VPN_2",
+        "type": "vxlan",
+    },
+]
+created_l2vpns = make_netbox_calls(nb.ipam.l2vpns, l2vpns)
+
 if ERRORS:
     sys.exit(
         "Errors have occurred when creating objects, and should have been printed out. Check previous output."
