@@ -5,13 +5,13 @@
 
 set -e
 
-VERSION="8.7.0"
-MAJOR="8"
+VERSION="9.6.1"
+MAJOR="9"
 
 # For idempotency, remove build data or built output first
 rm -rf ansible-build-data built
 
-pip3 install --user --upgrade antsibull
+pip3 install --user --upgrade "antsibull==0.63.1"
 git clone https://github.com/ansible-community/ansible-build-data.git
 mkdir -p built collection-cache
 BUILD_DATA_DIR="ansible-build-data/${MAJOR}"
